@@ -41,8 +41,8 @@
 #'                       comp.dist = list("norm", "norm"),
 #'                       comp.param = list(list("mean" = -2, "sd" = 0.5),
 #'                                         list("mean" = -1, "sd" = 1)))
-#' data1 <- getmixtData(mixt1)
-#' data2 <- getmixtData(mixt2)
+#' data1 <- get_mixture_data(mixt1)
+#' data2 <- get_mixture_data(mixt2)
 #' admixMod1 <- admix_model(knownComp_dist = mixt1$comp.dist[[2]],
 #'                          knownComp_param = mixt1$comp.param[[2]])
 #' admixMod2 <- admix_model(knownComp_dist = mixt2$comp.dist[[2]],
@@ -55,6 +55,8 @@
 
 admix_test <- function(samples, admixMod, test_method = c("poly","icv"), conf_level = 0.95, ...)
 {
+  if (!is.list(samples))
+    stop("Please provide sample(s) and admixture model(s) in lists, also with only one sample!")
   if (!all(sapply(X = admixMod, FUN = inherits, what = "admix_model")))
     stop("Argument 'admixMod' is not correctly specified. See ?admix_model.")
 
@@ -77,22 +79,22 @@ admix_test <- function(samples, admixMod, test_method = c("poly","icv"), conf_le
   if (meth == "icv") {
     if (n_samples >= 2) {
       test_res <- IBM_k_samples_test(samples = samples, admixMod = admixMod, conf_level = conf_level, ...)
-      #specific_class <- "IBM_test"
+      specific_class <- "IBM_test"
     } else stop("Incorrect number of samples under study (should be > 1).")
 
   } else if (meth == "poly") {
     if (n_samples == 1) {
       test_res <- gaussianity_test(sample = samples[[1]], admixMod = admixMod[[1]], conf_level = conf_level, ...)
-      #specific_class <- "gaussianity_test"
+      specific_class <- "gaussianity_test"
     } else {  # case when n_samples == 2
       test_res <- orthobasis_test(samples = samples, admixMod = admixMod, conf_level = conf_level, ...)
-      #specific_class <- "orthobasis_test"
+      specific_class <- "orthobasis_test"
     }
 
   } else stop("Please choose appropriately the arguments of the function.")
 
-  #class(test_res) <- c("htest", specific_class)
-  class(test_res) <- "htest"
+  class(test_res) <- c(specific_class, "htest")
+  #class(test_res) <- "htest"
   test_res$call <- match.call()
   return(test_res)
 }
